@@ -145,11 +145,11 @@ qlist_match(q_vdb_pkg_ctx *pkg_ctx, const char *name, depend_atom **name_atom, b
 	if (urepo) {
 		if (!pkg_ctx->repo)
 			q_vdb_pkg_eat(pkg_ctx, "repository", &pkg_ctx->repo, &pkg_ctx->repo_len);
-		urepo_len = strlen(urepo);
 		urepo += 2;
+		urepo_len = strlen(urepo);
 
 		if (uslot_len)
-			uslot_len -= urepo_len;
+			uslot_len -= (urepo_len + 2);
 	}
 
 	/* maybe they're using a version range */
@@ -183,8 +183,11 @@ qlist_match(q_vdb_pkg_ctx *pkg_ctx, const char *name, depend_atom **name_atom, b
 	}
 
 	if (uslot) {
-		/* require exact match on SLOTs */
-		if (strncmp(pkg_ctx->slot, uslot, uslot_len) != 0 || pkg_ctx->slot[uslot_len] != '\0')
+		/* Require exact match on SLOTs.  If the user didn't include a subslot,
+		 * then ignore it when checking the package's value. */
+		if (strncmp(pkg_ctx->slot, uslot, uslot_len) != 0 ||
+		    (pkg_ctx->slot[uslot_len] != '\0' &&
+		     pkg_ctx->slot[uslot_len] != '/'))
 			return false;
 	}
 
@@ -408,6 +411,9 @@ int qlist_main(int argc, char **argv)
 	state.atoms = xcalloc(argc - optind, sizeof(*state.atoms));
 	ret = q_vdb_foreach_pkg_sorted(qlist_cb, &state);
 	free(state.buf);
+	for (i = optind; i < state.argc; ++i)
+		if (state.atoms[i - optind])
+			atom_implode(state.atoms[i - optind]);
 	free(state.atoms);
 
 	/* The return value is whether we matched anything. */
