@@ -187,7 +187,7 @@ _q_static void qmerge_initialize(void)
 	}
 
 	char *buf;
-	xasprintf(&buf, "%s/portage", port_tmpdir);
+	xasprintf(&buf, "%s/portage/", port_tmpdir);
 	mkdir_p(buf, 0755);
 	xchdir(buf);
 
@@ -195,13 +195,10 @@ _q_static void qmerge_initialize(void)
 		if (force_download)
 			unlink(Packages);
 
-		if (access(Packages, R_OK) != 0) {
-			xasprintf(&buf, "%s/portage/", port_tmpdir);
-			if (access(Packages, R_OK) != 0)
-				fetch(buf, Packages);
-			free(buf);
-		}
+		if (access(Packages, R_OK) != 0)
+			fetch(buf, Packages);
 	}
+	free(buf);
 }
 
 struct qmerge_bv_state {
@@ -588,6 +585,7 @@ merge_tree_at(int fd_src, const char *src, int fd_dst, const char *dst,
 			/* syntax: obj filename hash mtime */
 			hash = hash_file_at(subfd_src, name, HASH_MD5);
 			fprintf(contents, "obj %s %s %"PRIu64"\n", cpath, hash, (uint64_t)st.st_mtime);
+			free(hash);
 
 			/* Check CONFIG_PROTECT */
 			if (config_protected(cpath, cp_argc, cp_argv, cpm_argc, cpm_argv)) {
@@ -870,12 +868,16 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 		return;
 	cat_ctx = q_vdb_open_cat(vdb_ctx, pkg->CATEGORY);
 	if (!cat_ctx) {
-		if (errno != ENOENT)
+		if (errno != ENOENT) {
+			q_vdb_close(vdb_ctx);
 			return;
+		}
 		mkdirat(vdb_ctx->vdb_fd, pkg->CATEGORY, 0755);
 		cat_ctx = q_vdb_open_cat(vdb_ctx, pkg->CATEGORY);
-		if (!cat_ctx)
+		if (!cat_ctx) {
+			q_vdb_close(vdb_ctx);
 			return;
+		}
 	}
 
 	/* Set up our temp dir to unpack this stuff */
@@ -982,13 +984,15 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 				warn("no idea how we reached here.");
 			case ERROR:
 			case NOT_EQUAL:
-				continue;
+				goto next_pkg;
 		}
 
 		qprintf("%s+++%s %s/%s %s %s/%s\n", GREEN, NORM, atom->CATEGORY, pkg->PF,
 			booga[ret], cat_ctx->name, pkg_ctx->name);
 
 		pkg_unmerge(pkg_ctx, objs);
+ next_pkg:
+		q_vdb_close_pkg(pkg_ctx);
 	}
 
 	/* Clean up the package state */
@@ -1019,6 +1023,8 @@ pkg_merge(int level, const depend_atom *atom, const struct pkg_t *pkg)
 	rmdir("../qmerge");
 
 	printf("%s>>>%s %s%s%s/%s%s%s\n", YELLOW, NORM, WHITE, atom->CATEGORY, NORM, CYAN, atom->PN, NORM);
+
+	q_vdb_close(vdb_ctx);
 }
 
 _q_static int
@@ -1050,7 +1056,7 @@ pkg_unmerge(q_vdb_pkg_ctx *pkg_ctx, queue *keep)
 	/* First get a handle on the things to clean up */
 	fp = q_vdb_pkg_fopenat_ro(pkg_ctx, "CONTENTS");
 	if (fp == NULL)
-		goto done;
+		return ret;
 
 	portroot_fd = cat_ctx->ctx->portroot_fd;
 
@@ -1102,6 +1108,7 @@ pkg_unmerge(q_vdb_pkg_ctx *pkg_ctx, queue *keep)
 					/* If the file wasn't modified, unmerge it */
 					unsigned char *hash = hash_file_at(portroot_fd, e->name + 1, HASH_MD5);
 					protected = strcmp(e->digest, (const char *)hash);
+					free(hash);
 				}
 				break;
 
@@ -1197,7 +1204,6 @@ pkg_unmerge(q_vdb_pkg_ctx *pkg_ctx, queue *keep)
 	}
 
 	ret = 0;
- done:
 	free(phases);
 	free(buf);
 
@@ -1232,6 +1238,7 @@ pkg_verify_checksums(char *fname, const struct pkg_t *pkg, const depend_atom *at
 				warn("MD5:  [%sER%s] (%s) != (%s) %s/%s", RED, NORM, hash, pkg->MD5, atom->CATEGORY, pkg->PF);
 			ret++;
 		}
+		free(hash);
 	}
 
 	if (pkg->SHA1[0]) {
@@ -1244,6 +1251,7 @@ pkg_verify_checksums(char *fname, const struct pkg_t *pkg, const depend_atom *at
 				warn("SHA1: [%sER%s] (%s) != (%s) %s/%s", RED, NORM, hash, pkg->SHA1, atom->CATEGORY, pkg->PF);
 			ret++;
 		}
+		free(hash);
 	}
 
 	if (!pkg->SHA1[0] && !pkg->MD5[0])
